@@ -22,6 +22,7 @@ use constant {
         '台灣好新聞 TaiwanHot.net',
         '工商時報',
         '新頭殼 Newtalk',
+        '新頭殼',
         '旺報',
         '無綫新聞',
         '聯合新聞網',
@@ -44,6 +45,7 @@ use constant {
     ],
 
     CATEGORY_NAMES => [
+        '科技',
         '美股',
         '台股新聞',
         '生活',
@@ -53,6 +55,7 @@ use constant {
         '國際',
         '軍視界',
         '生活發現',
+        '重點新聞',
     ],
 };
 
